==> haskell-bloomfilter-2.0.1.0-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-bloomfilter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bloomfilter
version: 2.0.1.0
id: bloomfilter-2.0.1.0-75m9ffhwms5ATxvYojZUwC
key: bloomfilter-2.0.1.0-75m9ffhwms5ATxvYojZUwC
license: BSD3
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability: provisional
homepage: https://github.com/bos/bloomfilter
synopsis: Pure and impure Bloom Filter implementations.
description:
    Pure and impure Bloom Filter implementations.
category: Data
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.BloomFilter Data.BloomFilter.Easy Data.BloomFilter.Mutable
    Data.BloomFilter.Hash
hidden-modules: Data.BloomFilter.Array
                Data.BloomFilter.Mutable.Internal Data.BloomFilter.Util
abi: a593ed9a22acc26feed6d5e209309ef2
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/bloomfilter-2.0.1.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/bloomfilter-2.0.1.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/bloomfilter-2.0.1.0
hs-libraries: HSbloomfilter-2.0.1.0-75m9ffhwms5ATxvYojZUwC
include-dirs: /usr/lib/ghc-8.0.1/site-local/bloomfilter-2.0.1.0/include
includes:
    lookup3.h
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 deepseq-1.4.2.0
haddock-interfaces: /usr/share/doc/haskell-bloomfilter/html/bloomfilter.haddock
haddock-html: /usr/share/doc/haskell-bloomfilter/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bloomfilter-2.0.1.0-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-bloomfilter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bloomfilter
version: 2.0.1.0
id: bloomfilter-2.0.1.0-JxHb4ZUCn159UMte89o3vh
key: bloomfilter-2.0.1.0-JxHb4ZUCn159UMte89o3vh
license: BSD3
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability: provisional
homepage: https://github.com/bos/bloomfilter
synopsis: Pure and impure Bloom Filter implementations.
description:
    Pure and impure Bloom Filter implementations.
category: Data
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.BloomFilter Data.BloomFilter.Easy Data.BloomFilter.Mutable
    Data.BloomFilter.Hash
hidden-modules: Data.BloomFilter.Array
                Data.BloomFilter.Mutable.Internal Data.BloomFilter.Util
abi: df70f6741500925effcc180ebb11148d
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/bloomfilter-2.0.1.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/bloomfilter-2.0.1.0
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/bloomfilter-2.0.1.0
hs-libraries: HSbloomfilter-2.0.1.0-JxHb4ZUCn159UMte89o3vh
include-dirs: /usr/lib/ghc-8.0.2/site-local/bloomfilter-2.0.1.0/include
includes:
    lookup3.h
depends:
    array-0.5.1.1 base-4.9.1.0 bytestring-0.10.8.1 deepseq-1.4.2.0
haddock-interfaces: /usr/share/doc/haskell-bloomfilter/html/bloomfilter.haddock
haddock-html: /usr/share/doc/haskell-bloomfilter/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
